# repacolors

Small library for color conversion, manipulation, etc.

[![Build Status](https://travis-ci.com/dyuri/repacolors.svg?branch=master)](https://travis-ci.com/dyuri/repacolors)

## Install

```
$ pip install repacolors
```

## `repacolor` command

### `display`

Display color in terminal (TODO conversion, manipulation, ...)

Example:
```
$ repacolor display red
$ repacolor display "#ffaad5"
```

### `pick`

Executes color picker (`xcolor`) and displays the picked color.

```
$ repacolor pick
```
